# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ContainerArgs', 'Container']

@pulumi.input_type
class ContainerArgs:
    def __init__(__self__, *,
                 namespace_id: pulumi.Input[_builtins.str],
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 deploy: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 health_checks: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]]] = None,
                 http_option: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 max_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 min_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_image: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_sha256: Optional[pulumi.Input[_builtins.str]] = None,
                 sandbox: Optional[pulumi.Input[_builtins.str]] = None,
                 scaling_options: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]]] = None,
                 secret_environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a Container resource.
        :param pulumi.Input[_builtins.str] namespace_id: The Containers namespace ID of the container.
               
               > **Important** Updating the `name` argument will recreate the container.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] commands: Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container.
        :param pulumi.Input[_builtins.bool] deploy: Boolean indicating whether the container is in a production environment.
        :param pulumi.Input[_builtins.str] description: The description of the container.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] environment_variables: The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        :param pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]] health_checks: Health check configuration block of the container.
        :param pulumi.Input[_builtins.str] http_option: Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        :param pulumi.Input[_builtins.int] local_storage_limit: Local storage limit of the container (in MB)
        :param pulumi.Input[_builtins.int] max_concurrency: The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        :param pulumi.Input[_builtins.int] max_scale: The maximum number of instances this container can scale to.
        :param pulumi.Input[_builtins.int] memory_limit: The memory resources in MB to allocate to each container.
        :param pulumi.Input[_builtins.int] min_scale: The minimum number of container instances running continuously.
        :param pulumi.Input[_builtins.str] name: The unique name of the container name.
        :param pulumi.Input[_builtins.int] port: The port to expose the container.
        :param pulumi.Input[_builtins.str] privacy: The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network the container is connected to.
               
               > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.
               
               Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        :param pulumi.Input[_builtins.str] protocol: The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the container was created.
        :param pulumi.Input[_builtins.str] registry_image: The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        :param pulumi.Input[_builtins.str] registry_sha256: The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        :param pulumi.Input[_builtins.str] sandbox: Execution environment of the container.
        :param pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]] scaling_options: Configuration block used to decide when to scale up or down. Possible values:
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] secret_environment_variables: The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        :param pulumi.Input[_builtins.str] status: The container status.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags associated with the container.
        :param pulumi.Input[_builtins.int] timeout: The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        pulumi.set(__self__, "namespace_id", namespace_id)
        if args is not None:
            pulumi.set(__self__, "args", args)
        if commands is not None:
            pulumi.set(__self__, "commands", commands)
        if cpu_limit is not None:
            pulumi.set(__self__, "cpu_limit", cpu_limit)
        if deploy is not None:
            pulumi.set(__self__, "deploy", deploy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if health_checks is not None:
            pulumi.set(__self__, "health_checks", health_checks)
        if http_option is not None:
            pulumi.set(__self__, "http_option", http_option)
        if local_storage_limit is not None:
            pulumi.set(__self__, "local_storage_limit", local_storage_limit)
        if max_concurrency is not None:
            warnings.warn("""Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""", DeprecationWarning)
            pulumi.log.warn("""max_concurrency is deprecated: Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""")
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if max_scale is not None:
            pulumi.set(__self__, "max_scale", max_scale)
        if memory_limit is not None:
            pulumi.set(__self__, "memory_limit", memory_limit)
        if min_scale is not None:
            pulumi.set(__self__, "min_scale", min_scale)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if privacy is not None:
            pulumi.set(__self__, "privacy", privacy)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if registry_image is not None:
            pulumi.set(__self__, "registry_image", registry_image)
        if registry_sha256 is not None:
            pulumi.set(__self__, "registry_sha256", registry_sha256)
        if sandbox is not None:
            pulumi.set(__self__, "sandbox", sandbox)
        if scaling_options is not None:
            pulumi.set(__self__, "scaling_options", scaling_options)
        if secret_environment_variables is not None:
            pulumi.set(__self__, "secret_environment_variables", secret_environment_variables)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Input[_builtins.str]:
        """
        The Containers namespace ID of the container.

        > **Important** Updating the `name` argument will recreate the container.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "namespace_id", value)

    @_builtins.property
    @pulumi.getter
    def args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        """
        return pulumi.get(self, "args")

    @args.setter
    def args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "args", value)

    @_builtins.property
    @pulumi.getter
    def commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        """
        return pulumi.get(self, "commands")

    @commands.setter
    def commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "commands", value)

    @_builtins.property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of vCPU computing resources to allocate to each container.
        """
        return pulumi.get(self, "cpu_limit")

    @cpu_limit.setter
    def cpu_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cpu_limit", value)

    @_builtins.property
    @pulumi.getter
    def deploy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean indicating whether the container is in a production environment.
        """
        return pulumi.get(self, "deploy")

    @deploy.setter
    def deploy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deploy", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the container.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "environment_variables", value)

    @_builtins.property
    @pulumi.getter(name="healthChecks")
    def health_checks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]]]:
        """
        Health check configuration block of the container.
        """
        return pulumi.get(self, "health_checks")

    @health_checks.setter
    def health_checks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]]]):
        pulumi.set(self, "health_checks", value)

    @_builtins.property
    @pulumi.getter(name="httpOption")
    def http_option(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        """
        return pulumi.get(self, "http_option")

    @http_option.setter
    def http_option(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "http_option", value)

    @_builtins.property
    @pulumi.getter(name="localStorageLimit")
    def local_storage_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Local storage limit of the container (in MB)
        """
        return pulumi.get(self, "local_storage_limit")

    @local_storage_limit.setter
    def local_storage_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_storage_limit", value)

    @_builtins.property
    @pulumi.getter(name="maxConcurrency")
    @_utilities.deprecated("""Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""")
    def max_concurrency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_concurrency", value)

    @_builtins.property
    @pulumi.getter(name="maxScale")
    def max_scale(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of instances this container can scale to.
        """
        return pulumi.get(self, "max_scale")

    @max_scale.setter
    def max_scale(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_scale", value)

    @_builtins.property
    @pulumi.getter(name="memoryLimit")
    def memory_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The memory resources in MB to allocate to each container.
        """
        return pulumi.get(self, "memory_limit")

    @memory_limit.setter
    def memory_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "memory_limit", value)

    @_builtins.property
    @pulumi.getter(name="minScale")
    def min_scale(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum number of container instances running continuously.
        """
        return pulumi.get(self, "min_scale")

    @min_scale.setter
    def min_scale(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_scale", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the container name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The port to expose the container.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def privacy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        """
        return pulumi.get(self, "privacy")

    @privacy.setter
    def privacy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Private Network the container is connected to.

        > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.

        Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Defaults to provider `region`) The region in which the container was created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="registryImage")
    def registry_image(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        """
        return pulumi.get(self, "registry_image")

    @registry_image.setter
    def registry_image(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_image", value)

    @_builtins.property
    @pulumi.getter(name="registrySha256")
    def registry_sha256(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        """
        return pulumi.get(self, "registry_sha256")

    @registry_sha256.setter
    def registry_sha256(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_sha256", value)

    @_builtins.property
    @pulumi.getter
    def sandbox(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Execution environment of the container.
        """
        return pulumi.get(self, "sandbox")

    @sandbox.setter
    def sandbox(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sandbox", value)

    @_builtins.property
    @pulumi.getter(name="scalingOptions")
    def scaling_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]]]:
        """
        Configuration block used to decide when to scale up or down. Possible values:
        """
        return pulumi.get(self, "scaling_options")

    @scaling_options.setter
    def scaling_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]]]):
        pulumi.set(self, "scaling_options", value)

    @_builtins.property
    @pulumi.getter(name="secretEnvironmentVariables")
    def secret_environment_variables(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        """
        return pulumi.get(self, "secret_environment_variables")

    @secret_environment_variables.setter
    def secret_environment_variables(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "secret_environment_variables", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The container status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags associated with the container.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.input_type
class _ContainerState:
    def __init__(__self__, *,
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 cron_status: Optional[pulumi.Input[_builtins.str]] = None,
                 deploy: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 domain_name: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 error_message: Optional[pulumi.Input[_builtins.str]] = None,
                 health_checks: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]]] = None,
                 http_option: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 max_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 min_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_image: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_sha256: Optional[pulumi.Input[_builtins.str]] = None,
                 sandbox: Optional[pulumi.Input[_builtins.str]] = None,
                 scaling_options: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]]] = None,
                 secret_environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering Container resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] commands: Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container.
        :param pulumi.Input[_builtins.str] cron_status: The cron status of the container.
        :param pulumi.Input[_builtins.bool] deploy: Boolean indicating whether the container is in a production environment.
        :param pulumi.Input[_builtins.str] description: The description of the container.
        :param pulumi.Input[_builtins.str] domain_name: The native domain name of the container
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] environment_variables: The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        :param pulumi.Input[_builtins.str] error_message: The error message of the container.
        :param pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]] health_checks: Health check configuration block of the container.
        :param pulumi.Input[_builtins.str] http_option: Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        :param pulumi.Input[_builtins.int] local_storage_limit: Local storage limit of the container (in MB)
        :param pulumi.Input[_builtins.int] max_concurrency: The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        :param pulumi.Input[_builtins.int] max_scale: The maximum number of instances this container can scale to.
        :param pulumi.Input[_builtins.int] memory_limit: The memory resources in MB to allocate to each container.
        :param pulumi.Input[_builtins.int] min_scale: The minimum number of container instances running continuously.
        :param pulumi.Input[_builtins.str] name: The unique name of the container name.
        :param pulumi.Input[_builtins.str] namespace_id: The Containers namespace ID of the container.
               
               > **Important** Updating the `name` argument will recreate the container.
        :param pulumi.Input[_builtins.int] port: The port to expose the container.
        :param pulumi.Input[_builtins.str] privacy: The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network the container is connected to.
               
               > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.
               
               Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        :param pulumi.Input[_builtins.str] protocol: The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the container was created.
        :param pulumi.Input[_builtins.str] registry_image: The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        :param pulumi.Input[_builtins.str] registry_sha256: The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        :param pulumi.Input[_builtins.str] sandbox: Execution environment of the container.
        :param pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]] scaling_options: Configuration block used to decide when to scale up or down. Possible values:
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] secret_environment_variables: The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        :param pulumi.Input[_builtins.str] status: The container status.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags associated with the container.
        :param pulumi.Input[_builtins.int] timeout: The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        if args is not None:
            pulumi.set(__self__, "args", args)
        if commands is not None:
            pulumi.set(__self__, "commands", commands)
        if cpu_limit is not None:
            pulumi.set(__self__, "cpu_limit", cpu_limit)
        if cron_status is not None:
            pulumi.set(__self__, "cron_status", cron_status)
        if deploy is not None:
            pulumi.set(__self__, "deploy", deploy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain_name is not None:
            pulumi.set(__self__, "domain_name", domain_name)
        if environment_variables is not None:
            pulumi.set(__self__, "environment_variables", environment_variables)
        if error_message is not None:
            pulumi.set(__self__, "error_message", error_message)
        if health_checks is not None:
            pulumi.set(__self__, "health_checks", health_checks)
        if http_option is not None:
            pulumi.set(__self__, "http_option", http_option)
        if local_storage_limit is not None:
            pulumi.set(__self__, "local_storage_limit", local_storage_limit)
        if max_concurrency is not None:
            warnings.warn("""Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""", DeprecationWarning)
            pulumi.log.warn("""max_concurrency is deprecated: Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""")
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if max_scale is not None:
            pulumi.set(__self__, "max_scale", max_scale)
        if memory_limit is not None:
            pulumi.set(__self__, "memory_limit", memory_limit)
        if min_scale is not None:
            pulumi.set(__self__, "min_scale", min_scale)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if privacy is not None:
            pulumi.set(__self__, "privacy", privacy)
        if private_network_id is not None:
            pulumi.set(__self__, "private_network_id", private_network_id)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if registry_image is not None:
            pulumi.set(__self__, "registry_image", registry_image)
        if registry_sha256 is not None:
            pulumi.set(__self__, "registry_sha256", registry_sha256)
        if sandbox is not None:
            pulumi.set(__self__, "sandbox", sandbox)
        if scaling_options is not None:
            pulumi.set(__self__, "scaling_options", scaling_options)
        if secret_environment_variables is not None:
            pulumi.set(__self__, "secret_environment_variables", secret_environment_variables)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)

    @_builtins.property
    @pulumi.getter
    def args(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        """
        return pulumi.get(self, "args")

    @args.setter
    def args(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "args", value)

    @_builtins.property
    @pulumi.getter
    def commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        """
        return pulumi.get(self, "commands")

    @commands.setter
    def commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "commands", value)

    @_builtins.property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The amount of vCPU computing resources to allocate to each container.
        """
        return pulumi.get(self, "cpu_limit")

    @cpu_limit.setter
    def cpu_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cpu_limit", value)

    @_builtins.property
    @pulumi.getter(name="cronStatus")
    def cron_status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The cron status of the container.
        """
        return pulumi.get(self, "cron_status")

    @cron_status.setter
    def cron_status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "cron_status", value)

    @_builtins.property
    @pulumi.getter
    def deploy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean indicating whether the container is in a production environment.
        """
        return pulumi.get(self, "deploy")

    @deploy.setter
    def deploy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deploy", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the container.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The native domain name of the container
        """
        return pulumi.get(self, "domain_name")

    @domain_name.setter
    def domain_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain_name", value)

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        """
        return pulumi.get(self, "environment_variables")

    @environment_variables.setter
    def environment_variables(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "environment_variables", value)

    @_builtins.property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The error message of the container.
        """
        return pulumi.get(self, "error_message")

    @error_message.setter
    def error_message(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "error_message", value)

    @_builtins.property
    @pulumi.getter(name="healthChecks")
    def health_checks(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]]]:
        """
        Health check configuration block of the container.
        """
        return pulumi.get(self, "health_checks")

    @health_checks.setter
    def health_checks(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckArgs']]]]):
        pulumi.set(self, "health_checks", value)

    @_builtins.property
    @pulumi.getter(name="httpOption")
    def http_option(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        """
        return pulumi.get(self, "http_option")

    @http_option.setter
    def http_option(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "http_option", value)

    @_builtins.property
    @pulumi.getter(name="localStorageLimit")
    def local_storage_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Local storage limit of the container (in MB)
        """
        return pulumi.get(self, "local_storage_limit")

    @local_storage_limit.setter
    def local_storage_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "local_storage_limit", value)

    @_builtins.property
    @pulumi.getter(name="maxConcurrency")
    @_utilities.deprecated("""Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""")
    def max_concurrency(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_concurrency", value)

    @_builtins.property
    @pulumi.getter(name="maxScale")
    def max_scale(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum number of instances this container can scale to.
        """
        return pulumi.get(self, "max_scale")

    @max_scale.setter
    def max_scale(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "max_scale", value)

    @_builtins.property
    @pulumi.getter(name="memoryLimit")
    def memory_limit(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The memory resources in MB to allocate to each container.
        """
        return pulumi.get(self, "memory_limit")

    @memory_limit.setter
    def memory_limit(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "memory_limit", value)

    @_builtins.property
    @pulumi.getter(name="minScale")
    def min_scale(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The minimum number of container instances running continuously.
        """
        return pulumi.get(self, "min_scale")

    @min_scale.setter
    def min_scale(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "min_scale", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The unique name of the container name.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Containers namespace ID of the container.

        > **Important** Updating the `name` argument will recreate the container.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace_id", value)

    @_builtins.property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The port to expose the container.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "port", value)

    @_builtins.property
    @pulumi.getter
    def privacy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        """
        return pulumi.get(self, "privacy")

    @privacy.setter
    def privacy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "privacy", value)

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the Private Network the container is connected to.

        > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.

        Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        """
        return pulumi.get(self, "private_network_id")

    @private_network_id.setter
    def private_network_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "private_network_id", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        (Defaults to provider `region`) The region in which the container was created.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="registryImage")
    def registry_image(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        """
        return pulumi.get(self, "registry_image")

    @registry_image.setter
    def registry_image(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_image", value)

    @_builtins.property
    @pulumi.getter(name="registrySha256")
    def registry_sha256(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        """
        return pulumi.get(self, "registry_sha256")

    @registry_sha256.setter
    def registry_sha256(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "registry_sha256", value)

    @_builtins.property
    @pulumi.getter
    def sandbox(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Execution environment of the container.
        """
        return pulumi.get(self, "sandbox")

    @sandbox.setter
    def sandbox(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sandbox", value)

    @_builtins.property
    @pulumi.getter(name="scalingOptions")
    def scaling_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]]]:
        """
        Configuration block used to decide when to scale up or down. Possible values:
        """
        return pulumi.get(self, "scaling_options")

    @scaling_options.setter
    def scaling_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ContainerScalingOptionArgs']]]]):
        pulumi.set(self, "scaling_options", value)

    @_builtins.property
    @pulumi.getter(name="secretEnvironmentVariables")
    def secret_environment_variables(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        """
        return pulumi.get(self, "secret_environment_variables")

    @secret_environment_variables.setter
    def secret_environment_variables(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "secret_environment_variables", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The container status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        The list of tags associated with the container.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)


@pulumi.type_token("scaleway:containers/container:Container")
class Container(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 deploy: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 health_checks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContainerHealthCheckArgs', 'ContainerHealthCheckArgsDict']]]]] = None,
                 http_option: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 max_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 min_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_image: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_sha256: Optional[pulumi.Input[_builtins.str]] = None,
                 sandbox: Optional[pulumi.Input[_builtins.str]] = None,
                 scaling_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContainerScalingOptionArgs', 'ContainerScalingOptionArgsDict']]]]] = None,
                 secret_environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        The `containers.Container` resource allows you to create and manage [Serverless Containers](https://www.scaleway.com/en/docs/serverless/containers/).

        Refer to the Serverless Containers [product documentation](https://www.scaleway.com/en/docs/serverless/containers/) and [API documentation](https://www.scaleway.com/en/developers/api/serverless-containers/) for more information.

        For more information on the limitations of Serverless Containers, refer to the [dedicated documentation](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/).

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Namespace("main",
            name="my-ns-test",
            description="test container")
        main_container = scaleway.containers.Container("main",
            name="my-container-02",
            description="environment variables test",
            tags=[
                "tag1",
                "tag2",
            ],
            namespace_id=main.id,
            registry_image=main.registry_endpoint.apply(lambda registry_endpoint: f"{registry_endpoint}/alpine:test"),
            port=9997,
            cpu_limit=1024,
            memory_limit=2048,
            min_scale=3,
            max_scale=5,
            timeout=600,
            max_concurrency=80,
            privacy="private",
            protocol="http1",
            deploy=True,
            commands=[
                "bash",
                "-c",
                "script.sh",
            ],
            args=[
                "some",
                "args",
            ],
            environment_variables={
                "foo": "var",
            },
            secret_environment_variables={
                "key": "secret",
            })
        ```

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        # Project to be referenced in the IAM policy
        default = scaleway.account.get_project(name="default")
        # IAM resources
        container_auth = scaleway.iam.Application("container_auth", name="container-auth")
        access_private_containers = scaleway.iam.Policy("access_private_containers",
            application_id=container_auth.id,
            rules=[{
                "project_ids": [default.id],
                "permission_set_names": ["ContainersPrivateAccess"],
            }])
        api_key = scaleway.iam.ApiKey("api_key", application_id=container_auth.id)
        # Container resources
        private = scaleway.containers.Namespace("private", name="private-container-namespace")
        private_container = scaleway.containers.Container("private",
            namespace_id=private.id,
            registry_image="rg.fr-par.scw.cloud/my-registry-ns/my-image:latest",
            privacy="private",
            deploy=True)
        pulumi.export("secretKey", api_key.secret_key)
        pulumi.export("containerEndpoint", private_container.domain_name)
        ```

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        # When using mutable images (e.g., `latest` tag), you can use the `scaleway_registry_image_tag` data source along 
        # with the `registry_sha256` argument to trigger container redeployments when the image is updated.
        # Ideally, you would create the namespace separately.
        # For demonstration purposes, this example assumes the "nginx:latest" image is already available
        # in the referenced namespace.
        main = scaleway.registry.Namespace("main", name="some-unique-name")
        nginx = scaleway.registry.get_image_output(namespace_id=main.id,
            name="nginx")
        nginx_latest = nginx.apply(lambda nginx: scaleway.registry.get_image_tag_output(image_id=nginx.id,
            name="latest"))
        main_namespace = scaleway.containers.Namespace("main", name="my-container-namespace")
        main_container = scaleway.containers.Container("main",
            name="nginx-latest",
            namespace_id=main_namespace.id,
            registry_image=main.endpoint.apply(lambda endpoint: f"{endpoint}/nginx:latest"),
            registry_sha256=nginx_latest.digest,
            port=80,
            deploy=True)
        ```

        ## Protocols

        The following protocols are supported:

        * `h2c`: HTTP/2 over TCP.
        * `http1`: Hypertext Transfer Protocol.

        > **Important:** Refer to the official [Apache documentation](https://httpd.apache.org/docs/2.4/howto/http2.html) for more information.

        ## Privacy

        By default, creating a container will make it `public`, meaning that anybody knowing the endpoint can execute it.

        A container can be made `private` with the privacy parameter.

        Refer to the [technical information](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8) for more information on container authentication.

        ## Memory and vCPUs configuration

        The vCPU represents a portion of the underlying, physical CPU that is assigned to a particular virtual machine (VM).

        You can determine the computing resources to allocate to each container.

        The `memory_limit` (in MB) must correspond with the right amount of vCPU. Refer to the table below to determine the right memory/vCPU combination.

        | Memory (in MB) | vCPU |
        |----------------|------|
        | 128            | 70m  |
        | 256            | 140m |
        | 512            | 280m |
        | 1024           | 560m |
        | 2048           | 1120 |
        | 3072           | 1680 |
        | 4096           | 2240 |

        ~>**Important:** Make sure to select the right resources, as you will be billed based on compute usage over time and the number of Containers executions.
        Refer to the [Serverless Containers pricing](https://www.scaleway.com/en/docs/faq/serverless-containers/#prices) for more information.

        ## Health check configuration

        Custom health checks can be configured on the container.

        It's possible to specify the HTTP path that the probe will listen to and the number of failures before considering the container as unhealthy.
        During a deployment, if a newly created container fails to pass the health check, the deployment is aborted.
        As a result, lowering this value can help to reduce the time it takes to detect a failed deployment.
        The period between health checks is also configurable.

        Example:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Container("main",
            name="my-container-02",
            namespace_id=main_scaleway_container_namespace["id"],
            health_checks=[{
                "https": [{
                    "path": "/ping",
                }],
                "failure_threshold": 40,
                "interval": "5s",
            }])
        ```

        ~>**Important:** Another probe type can be set to TCP with the API, but currently the SDK has not been updated with this parameter.
        This is why the only probe that can be used here is the HTTP probe.
        Refer to the [Serverless Containers pricing](https://www.scaleway.com/en/docs/faq/serverless-containers/#prices) for more information.

        ## Scaling option configuration

        Scaling option block configuration allows you to choose which parameter will scale up/down containers.
        Options are number of concurrent requests, CPU or memory usage.
        It replaces current `max_concurrency` that has been deprecated.

        Example:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Container("main",
            name="my-container-02",
            namespace_id=main_scaleway_container_namespace["id"],
            scaling_options=[{
                "concurrent_requests_threshold": 15,
            }])
        ```

        ~>**Important**: A maximum of one of these parameters may be set. Also, when `cpu_usage_threshold` or `memory_usage_threshold` are used, `min_scale` can't be set to 0.
        Refer to the [API Reference](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-create-a-new-container) for more information.

        ## Import

        Containers can be imported using, `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:containers/container:Container main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] commands: Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container.
        :param pulumi.Input[_builtins.bool] deploy: Boolean indicating whether the container is in a production environment.
        :param pulumi.Input[_builtins.str] description: The description of the container.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] environment_variables: The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContainerHealthCheckArgs', 'ContainerHealthCheckArgsDict']]]] health_checks: Health check configuration block of the container.
        :param pulumi.Input[_builtins.str] http_option: Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        :param pulumi.Input[_builtins.int] local_storage_limit: Local storage limit of the container (in MB)
        :param pulumi.Input[_builtins.int] max_concurrency: The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        :param pulumi.Input[_builtins.int] max_scale: The maximum number of instances this container can scale to.
        :param pulumi.Input[_builtins.int] memory_limit: The memory resources in MB to allocate to each container.
        :param pulumi.Input[_builtins.int] min_scale: The minimum number of container instances running continuously.
        :param pulumi.Input[_builtins.str] name: The unique name of the container name.
        :param pulumi.Input[_builtins.str] namespace_id: The Containers namespace ID of the container.
               
               > **Important** Updating the `name` argument will recreate the container.
        :param pulumi.Input[_builtins.int] port: The port to expose the container.
        :param pulumi.Input[_builtins.str] privacy: The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network the container is connected to.
               
               > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.
               
               Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        :param pulumi.Input[_builtins.str] protocol: The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the container was created.
        :param pulumi.Input[_builtins.str] registry_image: The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        :param pulumi.Input[_builtins.str] registry_sha256: The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        :param pulumi.Input[_builtins.str] sandbox: Execution environment of the container.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContainerScalingOptionArgs', 'ContainerScalingOptionArgsDict']]]] scaling_options: Configuration block used to decide when to scale up or down. Possible values:
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] secret_environment_variables: The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        :param pulumi.Input[_builtins.str] status: The container status.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags associated with the container.
        :param pulumi.Input[_builtins.int] timeout: The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ContainerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `containers.Container` resource allows you to create and manage [Serverless Containers](https://www.scaleway.com/en/docs/serverless/containers/).

        Refer to the Serverless Containers [product documentation](https://www.scaleway.com/en/docs/serverless/containers/) and [API documentation](https://www.scaleway.com/en/developers/api/serverless-containers/) for more information.

        For more information on the limitations of Serverless Containers, refer to the [dedicated documentation](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/).

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Namespace("main",
            name="my-ns-test",
            description="test container")
        main_container = scaleway.containers.Container("main",
            name="my-container-02",
            description="environment variables test",
            tags=[
                "tag1",
                "tag2",
            ],
            namespace_id=main.id,
            registry_image=main.registry_endpoint.apply(lambda registry_endpoint: f"{registry_endpoint}/alpine:test"),
            port=9997,
            cpu_limit=1024,
            memory_limit=2048,
            min_scale=3,
            max_scale=5,
            timeout=600,
            max_concurrency=80,
            privacy="private",
            protocol="http1",
            deploy=True,
            commands=[
                "bash",
                "-c",
                "script.sh",
            ],
            args=[
                "some",
                "args",
            ],
            environment_variables={
                "foo": "var",
            },
            secret_environment_variables={
                "key": "secret",
            })
        ```

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        # Project to be referenced in the IAM policy
        default = scaleway.account.get_project(name="default")
        # IAM resources
        container_auth = scaleway.iam.Application("container_auth", name="container-auth")
        access_private_containers = scaleway.iam.Policy("access_private_containers",
            application_id=container_auth.id,
            rules=[{
                "project_ids": [default.id],
                "permission_set_names": ["ContainersPrivateAccess"],
            }])
        api_key = scaleway.iam.ApiKey("api_key", application_id=container_auth.id)
        # Container resources
        private = scaleway.containers.Namespace("private", name="private-container-namespace")
        private_container = scaleway.containers.Container("private",
            namespace_id=private.id,
            registry_image="rg.fr-par.scw.cloud/my-registry-ns/my-image:latest",
            privacy="private",
            deploy=True)
        pulumi.export("secretKey", api_key.secret_key)
        pulumi.export("containerEndpoint", private_container.domain_name)
        ```

        ```python
        import pulumi
        import pulumi_scaleway as scaleway
        import pulumiverse_scaleway as scaleway

        # When using mutable images (e.g., `latest` tag), you can use the `scaleway_registry_image_tag` data source along 
        # with the `registry_sha256` argument to trigger container redeployments when the image is updated.
        # Ideally, you would create the namespace separately.
        # For demonstration purposes, this example assumes the "nginx:latest" image is already available
        # in the referenced namespace.
        main = scaleway.registry.Namespace("main", name="some-unique-name")
        nginx = scaleway.registry.get_image_output(namespace_id=main.id,
            name="nginx")
        nginx_latest = nginx.apply(lambda nginx: scaleway.registry.get_image_tag_output(image_id=nginx.id,
            name="latest"))
        main_namespace = scaleway.containers.Namespace("main", name="my-container-namespace")
        main_container = scaleway.containers.Container("main",
            name="nginx-latest",
            namespace_id=main_namespace.id,
            registry_image=main.endpoint.apply(lambda endpoint: f"{endpoint}/nginx:latest"),
            registry_sha256=nginx_latest.digest,
            port=80,
            deploy=True)
        ```

        ## Protocols

        The following protocols are supported:

        * `h2c`: HTTP/2 over TCP.
        * `http1`: Hypertext Transfer Protocol.

        > **Important:** Refer to the official [Apache documentation](https://httpd.apache.org/docs/2.4/howto/http2.html) for more information.

        ## Privacy

        By default, creating a container will make it `public`, meaning that anybody knowing the endpoint can execute it.

        A container can be made `private` with the privacy parameter.

        Refer to the [technical information](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8) for more information on container authentication.

        ## Memory and vCPUs configuration

        The vCPU represents a portion of the underlying, physical CPU that is assigned to a particular virtual machine (VM).

        You can determine the computing resources to allocate to each container.

        The `memory_limit` (in MB) must correspond with the right amount of vCPU. Refer to the table below to determine the right memory/vCPU combination.

        | Memory (in MB) | vCPU |
        |----------------|------|
        | 128            | 70m  |
        | 256            | 140m |
        | 512            | 280m |
        | 1024           | 560m |
        | 2048           | 1120 |
        | 3072           | 1680 |
        | 4096           | 2240 |

        ~>**Important:** Make sure to select the right resources, as you will be billed based on compute usage over time and the number of Containers executions.
        Refer to the [Serverless Containers pricing](https://www.scaleway.com/en/docs/faq/serverless-containers/#prices) for more information.

        ## Health check configuration

        Custom health checks can be configured on the container.

        It's possible to specify the HTTP path that the probe will listen to and the number of failures before considering the container as unhealthy.
        During a deployment, if a newly created container fails to pass the health check, the deployment is aborted.
        As a result, lowering this value can help to reduce the time it takes to detect a failed deployment.
        The period between health checks is also configurable.

        Example:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Container("main",
            name="my-container-02",
            namespace_id=main_scaleway_container_namespace["id"],
            health_checks=[{
                "https": [{
                    "path": "/ping",
                }],
                "failure_threshold": 40,
                "interval": "5s",
            }])
        ```

        ~>**Important:** Another probe type can be set to TCP with the API, but currently the SDK has not been updated with this parameter.
        This is why the only probe that can be used here is the HTTP probe.
        Refer to the [Serverless Containers pricing](https://www.scaleway.com/en/docs/faq/serverless-containers/#prices) for more information.

        ## Scaling option configuration

        Scaling option block configuration allows you to choose which parameter will scale up/down containers.
        Options are number of concurrent requests, CPU or memory usage.
        It replaces current `max_concurrency` that has been deprecated.

        Example:

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.containers.Container("main",
            name="my-container-02",
            namespace_id=main_scaleway_container_namespace["id"],
            scaling_options=[{
                "concurrent_requests_threshold": 15,
            }])
        ```

        ~>**Important**: A maximum of one of these parameters may be set. Also, when `cpu_usage_threshold` or `memory_usage_threshold` are used, `min_scale` can't be set to 0.
        Refer to the [API Reference](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-create-a-new-container) for more information.

        ## Import

        Containers can be imported using, `{region}/{id}`, as shown below:

        bash

        ```sh
        $ pulumi import scaleway:containers/container:Container main fr-par/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param ContainerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ContainerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 deploy: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 health_checks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContainerHealthCheckArgs', 'ContainerHealthCheckArgsDict']]]]] = None,
                 http_option: Optional[pulumi.Input[_builtins.str]] = None,
                 local_storage_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 max_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
                 max_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
                 min_scale: Optional[pulumi.Input[_builtins.int]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 namespace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 port: Optional[pulumi.Input[_builtins.int]] = None,
                 privacy: Optional[pulumi.Input[_builtins.str]] = None,
                 private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_image: Optional[pulumi.Input[_builtins.str]] = None,
                 registry_sha256: Optional[pulumi.Input[_builtins.str]] = None,
                 sandbox: Optional[pulumi.Input[_builtins.str]] = None,
                 scaling_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContainerScalingOptionArgs', 'ContainerScalingOptionArgsDict']]]]] = None,
                 secret_environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ContainerArgs.__new__(ContainerArgs)

            __props__.__dict__["args"] = args
            __props__.__dict__["commands"] = commands
            __props__.__dict__["cpu_limit"] = cpu_limit
            __props__.__dict__["deploy"] = deploy
            __props__.__dict__["description"] = description
            __props__.__dict__["environment_variables"] = environment_variables
            __props__.__dict__["health_checks"] = health_checks
            __props__.__dict__["http_option"] = http_option
            __props__.__dict__["local_storage_limit"] = local_storage_limit
            __props__.__dict__["max_concurrency"] = max_concurrency
            __props__.__dict__["max_scale"] = max_scale
            __props__.__dict__["memory_limit"] = memory_limit
            __props__.__dict__["min_scale"] = min_scale
            __props__.__dict__["name"] = name
            if namespace_id is None and not opts.urn:
                raise TypeError("Missing required property 'namespace_id'")
            __props__.__dict__["namespace_id"] = namespace_id
            __props__.__dict__["port"] = port
            __props__.__dict__["privacy"] = privacy
            __props__.__dict__["private_network_id"] = private_network_id
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["region"] = region
            __props__.__dict__["registry_image"] = registry_image
            __props__.__dict__["registry_sha256"] = registry_sha256
            __props__.__dict__["sandbox"] = sandbox
            __props__.__dict__["scaling_options"] = scaling_options
            __props__.__dict__["secret_environment_variables"] = None if secret_environment_variables is None else pulumi.Output.secret(secret_environment_variables)
            __props__.__dict__["status"] = status
            __props__.__dict__["tags"] = tags
            __props__.__dict__["timeout"] = timeout
            __props__.__dict__["cron_status"] = None
            __props__.__dict__["domain_name"] = None
            __props__.__dict__["error_message"] = None
        alias_opts = pulumi.ResourceOptions(aliases=[pulumi.Alias(type_="scaleway:index/container:Container")])
        opts = pulumi.ResourceOptions.merge(opts, alias_opts)
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretEnvironmentVariables"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(Container, __self__).__init__(
            'scaleway:containers/container:Container',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            args: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            commands: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            cpu_limit: Optional[pulumi.Input[_builtins.int]] = None,
            cron_status: Optional[pulumi.Input[_builtins.str]] = None,
            deploy: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            domain_name: Optional[pulumi.Input[_builtins.str]] = None,
            environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            error_message: Optional[pulumi.Input[_builtins.str]] = None,
            health_checks: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContainerHealthCheckArgs', 'ContainerHealthCheckArgsDict']]]]] = None,
            http_option: Optional[pulumi.Input[_builtins.str]] = None,
            local_storage_limit: Optional[pulumi.Input[_builtins.int]] = None,
            max_concurrency: Optional[pulumi.Input[_builtins.int]] = None,
            max_scale: Optional[pulumi.Input[_builtins.int]] = None,
            memory_limit: Optional[pulumi.Input[_builtins.int]] = None,
            min_scale: Optional[pulumi.Input[_builtins.int]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            namespace_id: Optional[pulumi.Input[_builtins.str]] = None,
            port: Optional[pulumi.Input[_builtins.int]] = None,
            privacy: Optional[pulumi.Input[_builtins.str]] = None,
            private_network_id: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            registry_image: Optional[pulumi.Input[_builtins.str]] = None,
            registry_sha256: Optional[pulumi.Input[_builtins.str]] = None,
            sandbox: Optional[pulumi.Input[_builtins.str]] = None,
            scaling_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ContainerScalingOptionArgs', 'ContainerScalingOptionArgsDict']]]]] = None,
            secret_environment_variables: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            timeout: Optional[pulumi.Input[_builtins.int]] = None) -> 'Container':
        """
        Get an existing Container resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] args: Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] commands: Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        :param pulumi.Input[_builtins.int] cpu_limit: The amount of vCPU computing resources to allocate to each container.
        :param pulumi.Input[_builtins.str] cron_status: The cron status of the container.
        :param pulumi.Input[_builtins.bool] deploy: Boolean indicating whether the container is in a production environment.
        :param pulumi.Input[_builtins.str] description: The description of the container.
        :param pulumi.Input[_builtins.str] domain_name: The native domain name of the container
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] environment_variables: The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        :param pulumi.Input[_builtins.str] error_message: The error message of the container.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContainerHealthCheckArgs', 'ContainerHealthCheckArgsDict']]]] health_checks: Health check configuration block of the container.
        :param pulumi.Input[_builtins.str] http_option: Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        :param pulumi.Input[_builtins.int] local_storage_limit: Local storage limit of the container (in MB)
        :param pulumi.Input[_builtins.int] max_concurrency: The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        :param pulumi.Input[_builtins.int] max_scale: The maximum number of instances this container can scale to.
        :param pulumi.Input[_builtins.int] memory_limit: The memory resources in MB to allocate to each container.
        :param pulumi.Input[_builtins.int] min_scale: The minimum number of container instances running continuously.
        :param pulumi.Input[_builtins.str] name: The unique name of the container name.
        :param pulumi.Input[_builtins.str] namespace_id: The Containers namespace ID of the container.
               
               > **Important** Updating the `name` argument will recreate the container.
        :param pulumi.Input[_builtins.int] port: The port to expose the container.
        :param pulumi.Input[_builtins.str] privacy: The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        :param pulumi.Input[_builtins.str] private_network_id: The ID of the Private Network the container is connected to.
               
               > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.
               
               Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        :param pulumi.Input[_builtins.str] protocol: The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        :param pulumi.Input[_builtins.str] region: (Defaults to provider `region`) The region in which the container was created.
        :param pulumi.Input[_builtins.str] registry_image: The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        :param pulumi.Input[_builtins.str] registry_sha256: The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        :param pulumi.Input[_builtins.str] sandbox: Execution environment of the container.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ContainerScalingOptionArgs', 'ContainerScalingOptionArgsDict']]]] scaling_options: Configuration block used to decide when to scale up or down. Possible values:
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] secret_environment_variables: The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        :param pulumi.Input[_builtins.str] status: The container status.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: The list of tags associated with the container.
        :param pulumi.Input[_builtins.int] timeout: The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ContainerState.__new__(_ContainerState)

        __props__.__dict__["args"] = args
        __props__.__dict__["commands"] = commands
        __props__.__dict__["cpu_limit"] = cpu_limit
        __props__.__dict__["cron_status"] = cron_status
        __props__.__dict__["deploy"] = deploy
        __props__.__dict__["description"] = description
        __props__.__dict__["domain_name"] = domain_name
        __props__.__dict__["environment_variables"] = environment_variables
        __props__.__dict__["error_message"] = error_message
        __props__.__dict__["health_checks"] = health_checks
        __props__.__dict__["http_option"] = http_option
        __props__.__dict__["local_storage_limit"] = local_storage_limit
        __props__.__dict__["max_concurrency"] = max_concurrency
        __props__.__dict__["max_scale"] = max_scale
        __props__.__dict__["memory_limit"] = memory_limit
        __props__.__dict__["min_scale"] = min_scale
        __props__.__dict__["name"] = name
        __props__.__dict__["namespace_id"] = namespace_id
        __props__.__dict__["port"] = port
        __props__.__dict__["privacy"] = privacy
        __props__.__dict__["private_network_id"] = private_network_id
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["region"] = region
        __props__.__dict__["registry_image"] = registry_image
        __props__.__dict__["registry_sha256"] = registry_sha256
        __props__.__dict__["sandbox"] = sandbox
        __props__.__dict__["scaling_options"] = scaling_options
        __props__.__dict__["secret_environment_variables"] = secret_environment_variables
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["timeout"] = timeout
        return Container(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def args(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Arguments passed to the command specified in the "command" field. These override the default arguments from the container image, and behave like command-line parameters.
        """
        return pulumi.get(self, "args")

    @_builtins.property
    @pulumi.getter
    def commands(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Command executed when the container starts. This overrides the default command defined in the container image. This is usually the main executable, or entry point script to run.
        """
        return pulumi.get(self, "commands")

    @_builtins.property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> pulumi.Output[_builtins.int]:
        """
        The amount of vCPU computing resources to allocate to each container.
        """
        return pulumi.get(self, "cpu_limit")

    @_builtins.property
    @pulumi.getter(name="cronStatus")
    def cron_status(self) -> pulumi.Output[_builtins.str]:
        """
        The cron status of the container.
        """
        return pulumi.get(self, "cron_status")

    @_builtins.property
    @pulumi.getter
    def deploy(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Boolean indicating whether the container is in a production environment.
        """
        return pulumi.get(self, "deploy")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the container.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="domainName")
    def domain_name(self) -> pulumi.Output[_builtins.str]:
        """
        The native domain name of the container
        """
        return pulumi.get(self, "domain_name")

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> pulumi.Output[Mapping[str, _builtins.str]]:
        """
        The [environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#environment-variables) of the container.
        """
        return pulumi.get(self, "environment_variables")

    @_builtins.property
    @pulumi.getter(name="errorMessage")
    def error_message(self) -> pulumi.Output[_builtins.str]:
        """
        The error message of the container.
        """
        return pulumi.get(self, "error_message")

    @_builtins.property
    @pulumi.getter(name="healthChecks")
    def health_checks(self) -> pulumi.Output[Sequence['outputs.ContainerHealthCheck']]:
        """
        Health check configuration block of the container.
        """
        return pulumi.get(self, "health_checks")

    @_builtins.property
    @pulumi.getter(name="httpOption")
    def http_option(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Allows both HTTP and HTTPS (`enabled`) or redirect HTTP to HTTPS (`redirected`). Defaults to `enabled`.
        """
        return pulumi.get(self, "http_option")

    @_builtins.property
    @pulumi.getter(name="localStorageLimit")
    def local_storage_limit(self) -> pulumi.Output[_builtins.int]:
        """
        Local storage limit of the container (in MB)
        """
        return pulumi.get(self, "local_storage_limit")

    @_builtins.property
    @pulumi.getter(name="maxConcurrency")
    @_utilities.deprecated("""Use scaling_option.concurrent_requests_threshold instead. This attribute will be removed.""")
    def max_concurrency(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum number of simultaneous requests your container can handle at the same time. Use `scaling_option.concurrent_requests_threshold` instead.
        """
        return pulumi.get(self, "max_concurrency")

    @_builtins.property
    @pulumi.getter(name="maxScale")
    def max_scale(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum number of instances this container can scale to.
        """
        return pulumi.get(self, "max_scale")

    @_builtins.property
    @pulumi.getter(name="memoryLimit")
    def memory_limit(self) -> pulumi.Output[_builtins.int]:
        """
        The memory resources in MB to allocate to each container.
        """
        return pulumi.get(self, "memory_limit")

    @_builtins.property
    @pulumi.getter(name="minScale")
    def min_scale(self) -> pulumi.Output[_builtins.int]:
        """
        The minimum number of container instances running continuously.
        """
        return pulumi.get(self, "min_scale")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The unique name of the container name.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="namespaceId")
    def namespace_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Containers namespace ID of the container.

        > **Important** Updating the `name` argument will recreate the container.
        """
        return pulumi.get(self, "namespace_id")

    @_builtins.property
    @pulumi.getter
    def port(self) -> pulumi.Output[_builtins.int]:
        """
        The port to expose the container.
        """
        return pulumi.get(self, "port")

    @_builtins.property
    @pulumi.getter
    def privacy(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The privacy type defines the way to authenticate to your container. Please check our dedicated [section](https://www.scaleway.com/en/developers/api/serverless-containers/#protocol-9dd4c8).
        """
        return pulumi.get(self, "privacy")

    @_builtins.property
    @pulumi.getter(name="privateNetworkId")
    def private_network_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The ID of the Private Network the container is connected to.

        > **Important** This feature is currently in beta and requires a namespace with VPC integration activated by setting the `activate_vpc_integration` attribute to `true`.

        Note that if you want to use your own configuration, you must consult our configuration [restrictions](https://www.scaleway.com/en/docs/serverless-containers/reference-content/containers-limitations/#configuration-restrictions) section.
        """
        return pulumi.get(self, "private_network_id")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The communication [protocol](https://www.scaleway.com/en/developers/api/serverless-containers/#path-containers-update-an-existing-container) `http1` or `h2c`. Defaults to `http1`.
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        (Defaults to provider `region`) The region in which the container was created.
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="registryImage")
    def registry_image(self) -> pulumi.Output[_builtins.str]:
        """
        The registry image address (e.g., `rg.fr-par.scw.cloud/$NAMESPACE/$IMAGE`)
        """
        return pulumi.get(self, "registry_image")

    @_builtins.property
    @pulumi.getter(name="registrySha256")
    def registry_sha256(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The sha256 of your source registry image, changing it will re-apply the deployment. Can be any string.
        """
        return pulumi.get(self, "registry_sha256")

    @_builtins.property
    @pulumi.getter
    def sandbox(self) -> pulumi.Output[_builtins.str]:
        """
        Execution environment of the container.
        """
        return pulumi.get(self, "sandbox")

    @_builtins.property
    @pulumi.getter(name="scalingOptions")
    def scaling_options(self) -> pulumi.Output[Sequence['outputs.ContainerScalingOption']]:
        """
        Configuration block used to decide when to scale up or down. Possible values:
        """
        return pulumi.get(self, "scaling_options")

    @_builtins.property
    @pulumi.getter(name="secretEnvironmentVariables")
    def secret_environment_variables(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        The [secret environment variables](https://www.scaleway.com/en/docs/serverless-containers/concepts/#secrets) of the container.
        """
        return pulumi.get(self, "secret_environment_variables")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The container status.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        The list of tags associated with the container.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[_builtins.int]:
        """
        The maximum amount of time in seconds your container can spend processing a request before being stopped. Default to `300` seconds.
        """
        return pulumi.get(self, "timeout")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetDeploymentResult',
    'AwaitableGetDeploymentResult',
    'get_deployment',
    'get_deployment_output',
]

@pulumi.output_type
class GetDeploymentResult:
    """
    A collection of values returned by getDeployment.
    """
    def __init__(__self__, created_at=None, deployment_id=None, endpoints=None, id=None, name=None, node_amount=None, node_type=None, password=None, private_networks=None, project_id=None, public_dashboard_url=None, region=None, status=None, tags=None, updated_at=None, user_name=None, version=None, volumes=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if endpoints and not isinstance(endpoints, list):
            raise TypeError("Expected argument 'endpoints' to be a list")
        pulumi.set(__self__, "endpoints", endpoints)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_amount and not isinstance(node_amount, int):
            raise TypeError("Expected argument 'node_amount' to be a int")
        pulumi.set(__self__, "node_amount", node_amount)
        if node_type and not isinstance(node_type, str):
            raise TypeError("Expected argument 'node_type' to be a str")
        pulumi.set(__self__, "node_type", node_type)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if private_networks and not isinstance(private_networks, list):
            raise TypeError("Expected argument 'private_networks' to be a list")
        pulumi.set(__self__, "private_networks", private_networks)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if public_dashboard_url and not isinstance(public_dashboard_url, str):
            raise TypeError("Expected argument 'public_dashboard_url' to be a str")
        pulumi.set(__self__, "public_dashboard_url", public_dashboard_url)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if user_name and not isinstance(user_name, str):
            raise TypeError("Expected argument 'user_name' to be a str")
        pulumi.set(__self__, "user_name", user_name)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)
        if volumes and not isinstance(volumes, list):
            raise TypeError("Expected argument 'volumes' to be a list")
        pulumi.set(__self__, "volumes", volumes)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "deployment_id")

    @_builtins.property
    @pulumi.getter
    def endpoints(self) -> Sequence['outputs.GetDeploymentEndpointResult']:
        return pulumi.get(self, "endpoints")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nodeAmount")
    def node_amount(self) -> _builtins.int:
        return pulumi.get(self, "node_amount")

    @_builtins.property
    @pulumi.getter(name="nodeType")
    def node_type(self) -> _builtins.str:
        return pulumi.get(self, "node_type")

    @_builtins.property
    @pulumi.getter
    def password(self) -> _builtins.str:
        return pulumi.get(self, "password")

    @_builtins.property
    @pulumi.getter(name="privateNetworks")
    def private_networks(self) -> Sequence['outputs.GetDeploymentPrivateNetworkResult']:
        return pulumi.get(self, "private_networks")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="publicDashboardUrl")
    def public_dashboard_url(self) -> _builtins.str:
        return pulumi.get(self, "public_dashboard_url")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> _builtins.str:
        return pulumi.get(self, "user_name")

    @_builtins.property
    @pulumi.getter
    def version(self) -> _builtins.str:
        return pulumi.get(self, "version")

    @_builtins.property
    @pulumi.getter
    def volumes(self) -> Sequence['outputs.GetDeploymentVolumeResult']:
        return pulumi.get(self, "volumes")


class AwaitableGetDeploymentResult(GetDeploymentResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDeploymentResult(
            created_at=self.created_at,
            deployment_id=self.deployment_id,
            endpoints=self.endpoints,
            id=self.id,
            name=self.name,
            node_amount=self.node_amount,
            node_type=self.node_type,
            password=self.password,
            private_networks=self.private_networks,
            project_id=self.project_id,
            public_dashboard_url=self.public_dashboard_url,
            region=self.region,
            status=self.status,
            tags=self.tags,
            updated_at=self.updated_at,
            user_name=self.user_name,
            version=self.version,
            volumes=self.volumes)


def get_deployment(deployment_id: Optional[_builtins.str] = None,
                   name: Optional[_builtins.str] = None,
                   project_id: Optional[_builtins.str] = None,
                   region: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDeploymentResult:
    """
    Gets information about an OpenSearch deployment.

    For more information refer to the [product documentation](https://www.scaleway.com/en/docs/opensearch/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    by_name = scaleway.opensearch.get_deployment(name="my-opensearch-cluster")
    # Get info by deployment ID
    by_id = scaleway.opensearch.get_deployment(deployment_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str deployment_id: The ID of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
    :param _builtins.str name: The name of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
    :param _builtins.str project_id: The ID of the project the OpenSearch deployment is associated with.
    :param _builtins.str region: `region`) The region in which the deployment exists.
    """
    __args__ = dict()
    __args__['deploymentId'] = deployment_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:opensearch/getDeployment:getDeployment', __args__, opts=opts, typ=GetDeploymentResult).value

    return AwaitableGetDeploymentResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        deployment_id=pulumi.get(__ret__, 'deployment_id'),
        endpoints=pulumi.get(__ret__, 'endpoints'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        node_amount=pulumi.get(__ret__, 'node_amount'),
        node_type=pulumi.get(__ret__, 'node_type'),
        password=pulumi.get(__ret__, 'password'),
        private_networks=pulumi.get(__ret__, 'private_networks'),
        project_id=pulumi.get(__ret__, 'project_id'),
        public_dashboard_url=pulumi.get(__ret__, 'public_dashboard_url'),
        region=pulumi.get(__ret__, 'region'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        user_name=pulumi.get(__ret__, 'user_name'),
        version=pulumi.get(__ret__, 'version'),
        volumes=pulumi.get(__ret__, 'volumes'))
def get_deployment_output(deployment_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDeploymentResult]:
    """
    Gets information about an OpenSearch deployment.

    For more information refer to the [product documentation](https://www.scaleway.com/en/docs/opensearch/).

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get info by name
    by_name = scaleway.opensearch.get_deployment(name="my-opensearch-cluster")
    # Get info by deployment ID
    by_id = scaleway.opensearch.get_deployment(deployment_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str deployment_id: The ID of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
    :param _builtins.str name: The name of the OpenSearch deployment. Only one of `name` and `deployment_id` should be specified.
    :param _builtins.str project_id: The ID of the project the OpenSearch deployment is associated with.
    :param _builtins.str region: `region`) The region in which the deployment exists.
    """
    __args__ = dict()
    __args__['deploymentId'] = deployment_id
    __args__['name'] = name
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:opensearch/getDeployment:getDeployment', __args__, opts=opts, typ=GetDeploymentResult)
    return __ret__.apply(lambda __response__: GetDeploymentResult(
        created_at=pulumi.get(__response__, 'created_at'),
        deployment_id=pulumi.get(__response__, 'deployment_id'),
        endpoints=pulumi.get(__response__, 'endpoints'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        node_amount=pulumi.get(__response__, 'node_amount'),
        node_type=pulumi.get(__response__, 'node_type'),
        password=pulumi.get(__response__, 'password'),
        private_networks=pulumi.get(__response__, 'private_networks'),
        project_id=pulumi.get(__response__, 'project_id'),
        public_dashboard_url=pulumi.get(__response__, 'public_dashboard_url'),
        region=pulumi.get(__response__, 'region'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        user_name=pulumi.get(__response__, 'user_name'),
        version=pulumi.get(__response__, 'version'),
        volumes=pulumi.get(__response__, 'volumes')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'KeyRotationPolicy',
    'GetKeyRotationPolicyResult',
]

@pulumi.output_type
class KeyRotationPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "rotationPeriod":
            suggest = "rotation_period"
        elif key == "nextRotationAt":
            suggest = "next_rotation_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in KeyRotationPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        KeyRotationPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        KeyRotationPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 rotation_period: _builtins.str,
                 next_rotation_at: Optional[_builtins.str] = None):
        """
        :param _builtins.str rotation_period: – The period between key rotations (e.g., `"720h"` for 30 days).
        :param _builtins.str next_rotation_at: The date and time of the next scheduled rotation.
        """
        pulumi.set(__self__, "rotation_period", rotation_period)
        if next_rotation_at is not None:
            pulumi.set(__self__, "next_rotation_at", next_rotation_at)

    @_builtins.property
    @pulumi.getter(name="rotationPeriod")
    def rotation_period(self) -> _builtins.str:
        """
        – The period between key rotations (e.g., `"720h"` for 30 days).
        """
        return pulumi.get(self, "rotation_period")

    @_builtins.property
    @pulumi.getter(name="nextRotationAt")
    def next_rotation_at(self) -> Optional[_builtins.str]:
        """
        The date and time of the next scheduled rotation.
        """
        return pulumi.get(self, "next_rotation_at")


@pulumi.output_type
class GetKeyRotationPolicyResult(dict):
    def __init__(__self__, *,
                 next_rotation_at: _builtins.str,
                 rotation_period: _builtins.str):
        """
        :param _builtins.str next_rotation_at: Timestamp indicating the next scheduled rotation.
        :param _builtins.str rotation_period: Time interval between two key rotations. The minimum duration is 24 hours and the maximum duration is 1 year (876000 hours).
        """
        pulumi.set(__self__, "next_rotation_at", next_rotation_at)
        pulumi.set(__self__, "rotation_period", rotation_period)

    @_builtins.property
    @pulumi.getter(name="nextRotationAt")
    def next_rotation_at(self) -> _builtins.str:
        """
        Timestamp indicating the next scheduled rotation.
        """
        return pulumi.get(self, "next_rotation_at")

    @_builtins.property
    @pulumi.getter(name="rotationPeriod")
    def rotation_period(self) -> _builtins.str:
        """
        Time interval between two key rotations. The minimum duration is 24 hours and the maximum duration is 1 year (876000 hours).
        """
        return pulumi.get(self, "rotation_period")





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBackendStageResult',
    'AwaitableGetBackendStageResult',
    'get_backend_stage',
    'get_backend_stage_output',
]

@pulumi.output_type
class GetBackendStageResult:
    """
    A collection of values returned by getBackendStage.
    """
    def __init__(__self__, backend_stage_id=None, bucket_name=None, bucket_region=None, created_at=None, id=None, lb_backend_configs=None, lb_id=None, pipeline_id=None, project_id=None, s3_backend_configs=None, updated_at=None):
        if backend_stage_id and not isinstance(backend_stage_id, str):
            raise TypeError("Expected argument 'backend_stage_id' to be a str")
        pulumi.set(__self__, "backend_stage_id", backend_stage_id)
        if bucket_name and not isinstance(bucket_name, str):
            raise TypeError("Expected argument 'bucket_name' to be a str")
        pulumi.set(__self__, "bucket_name", bucket_name)
        if bucket_region and not isinstance(bucket_region, str):
            raise TypeError("Expected argument 'bucket_region' to be a str")
        pulumi.set(__self__, "bucket_region", bucket_region)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lb_backend_configs and not isinstance(lb_backend_configs, list):
            raise TypeError("Expected argument 'lb_backend_configs' to be a list")
        pulumi.set(__self__, "lb_backend_configs", lb_backend_configs)
        if lb_id and not isinstance(lb_id, str):
            raise TypeError("Expected argument 'lb_id' to be a str")
        pulumi.set(__self__, "lb_id", lb_id)
        if pipeline_id and not isinstance(pipeline_id, str):
            raise TypeError("Expected argument 'pipeline_id' to be a str")
        pulumi.set(__self__, "pipeline_id", pipeline_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if s3_backend_configs and not isinstance(s3_backend_configs, list):
            raise TypeError("Expected argument 's3_backend_configs' to be a list")
        pulumi.set(__self__, "s3_backend_configs", s3_backend_configs)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="backendStageId")
    def backend_stage_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "backend_stage_id")

    @_builtins.property
    @pulumi.getter(name="bucketName")
    def bucket_name(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "bucket_name")

    @_builtins.property
    @pulumi.getter(name="bucketRegion")
    def bucket_region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "bucket_region")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lbBackendConfigs")
    def lb_backend_configs(self) -> Sequence['outputs.GetBackendStageLbBackendConfigResult']:
        return pulumi.get(self, "lb_backend_configs")

    @_builtins.property
    @pulumi.getter(name="lbId")
    def lb_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "lb_id")

    @_builtins.property
    @pulumi.getter(name="pipelineId")
    def pipeline_id(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "pipeline_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="s3BackendConfigs")
    def s3_backend_configs(self) -> Sequence['outputs.GetBackendStageS3BackendConfigResult']:
        return pulumi.get(self, "s3_backend_configs")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        return pulumi.get(self, "updated_at")


class AwaitableGetBackendStageResult(GetBackendStageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackendStageResult(
            backend_stage_id=self.backend_stage_id,
            bucket_name=self.bucket_name,
            bucket_region=self.bucket_region,
            created_at=self.created_at,
            id=self.id,
            lb_backend_configs=self.lb_backend_configs,
            lb_id=self.lb_id,
            pipeline_id=self.pipeline_id,
            project_id=self.project_id,
            s3_backend_configs=self.s3_backend_configs,
            updated_at=self.updated_at)


def get_backend_stage(backend_stage_id: Optional[_builtins.str] = None,
                      bucket_name: Optional[_builtins.str] = None,
                      bucket_region: Optional[_builtins.str] = None,
                      lb_id: Optional[_builtins.str] = None,
                      pipeline_id: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackendStageResult:
    """
    Gets information about an Edge Services backend stage.

    A backend stage defines the origin (Scaleway Object Storage bucket or Load Balancer) that Edge Services forwards requests to.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services backend stage by its ID
    by_id = scaleway.edgeservices.get_backend_stage(backend_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services backend stage by pipeline ID
    by_pipeline = scaleway.edgeservices.get_backend_stage(pipeline_id=main["id"])
    ```


    :param _builtins.str backend_stage_id: The ID of the backend stage.
           
           The following filter arguments are supported (cannot be used with `backend_stage_id`):
    :param _builtins.str bucket_name: Filter by S3 bucket name.
    :param _builtins.str bucket_region: Filter by S3 bucket region.
    :param _builtins.str lb_id: Filter by Load Balancer ID.
    :param _builtins.str pipeline_id: The ID of the pipeline.
    """
    __args__ = dict()
    __args__['backendStageId'] = backend_stage_id
    __args__['bucketName'] = bucket_name
    __args__['bucketRegion'] = bucket_region
    __args__['lbId'] = lb_id
    __args__['pipelineId'] = pipeline_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:edgeservices/getBackendStage:getBackendStage', __args__, opts=opts, typ=GetBackendStageResult).value

    return AwaitableGetBackendStageResult(
        backend_stage_id=pulumi.get(__ret__, 'backend_stage_id'),
        bucket_name=pulumi.get(__ret__, 'bucket_name'),
        bucket_region=pulumi.get(__ret__, 'bucket_region'),
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        lb_backend_configs=pulumi.get(__ret__, 'lb_backend_configs'),
        lb_id=pulumi.get(__ret__, 'lb_id'),
        pipeline_id=pulumi.get(__ret__, 'pipeline_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        s3_backend_configs=pulumi.get(__ret__, 's3_backend_configs'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_backend_stage_output(backend_stage_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             bucket_name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             bucket_region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             lb_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             pipeline_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetBackendStageResult]:
    """
    Gets information about an Edge Services backend stage.

    A backend stage defines the origin (Scaleway Object Storage bucket or Load Balancer) that Edge Services forwards requests to.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services backend stage by its ID
    by_id = scaleway.edgeservices.get_backend_stage(backend_stage_id="11111111-1111-1111-1111-111111111111")
    ```

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve an Edge Services backend stage by pipeline ID
    by_pipeline = scaleway.edgeservices.get_backend_stage(pipeline_id=main["id"])
    ```


    :param _builtins.str backend_stage_id: The ID of the backend stage.
           
           The following filter arguments are supported (cannot be used with `backend_stage_id`):
    :param _builtins.str bucket_name: Filter by S3 bucket name.
    :param _builtins.str bucket_region: Filter by S3 bucket region.
    :param _builtins.str lb_id: Filter by Load Balancer ID.
    :param _builtins.str pipeline_id: The ID of the pipeline.
    """
    __args__ = dict()
    __args__['backendStageId'] = backend_stage_id
    __args__['bucketName'] = bucket_name
    __args__['bucketRegion'] = bucket_region
    __args__['lbId'] = lb_id
    __args__['pipelineId'] = pipeline_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:edgeservices/getBackendStage:getBackendStage', __args__, opts=opts, typ=GetBackendStageResult)
    return __ret__.apply(lambda __response__: GetBackendStageResult(
        backend_stage_id=pulumi.get(__response__, 'backend_stage_id'),
        bucket_name=pulumi.get(__response__, 'bucket_name'),
        bucket_region=pulumi.get(__response__, 'bucket_region'),
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        lb_backend_configs=pulumi.get(__response__, 'lb_backend_configs'),
        lb_id=pulumi.get(__response__, 'lb_id'),
        pipeline_id=pulumi.get(__response__, 'pipeline_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        s3_backend_configs=pulumi.get(__response__, 's3_backend_configs'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ContainerHealthCheckArgs',
    'ContainerHealthCheckArgsDict',
    'ContainerHealthCheckHttpArgs',
    'ContainerHealthCheckHttpArgsDict',
    'ContainerScalingOptionArgs',
    'ContainerScalingOptionArgsDict',
    'TriggerNatsArgs',
    'TriggerNatsArgsDict',
    'TriggerSqsArgs',
    'TriggerSqsArgsDict',
]

MYPY = False

if not MYPY:
    class ContainerHealthCheckArgsDict(TypedDict):
        failure_threshold: pulumi.Input[_builtins.int]
        """
        Number of consecutive health check failures before considering the container unhealthy.
        """
        https: pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckHttpArgsDict']]]
        """
        HTTP health check configuration.
        """
        interval: pulumi.Input[_builtins.str]
        """
        Period between health checks (in seconds).
        """
elif False:
    ContainerHealthCheckArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ContainerHealthCheckArgs:
    def __init__(__self__, *,
                 failure_threshold: pulumi.Input[_builtins.int],
                 https: pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckHttpArgs']]],
                 interval: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.int] failure_threshold: Number of consecutive health check failures before considering the container unhealthy.
        :param pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckHttpArgs']]] https: HTTP health check configuration.
        :param pulumi.Input[_builtins.str] interval: Period between health checks (in seconds).
        """
        pulumi.set(__self__, "failure_threshold", failure_threshold)
        pulumi.set(__self__, "https", https)
        pulumi.set(__self__, "interval", interval)

    @_builtins.property
    @pulumi.getter(name="failureThreshold")
    def failure_threshold(self) -> pulumi.Input[_builtins.int]:
        """
        Number of consecutive health check failures before considering the container unhealthy.
        """
        return pulumi.get(self, "failure_threshold")

    @failure_threshold.setter
    def failure_threshold(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "failure_threshold", value)

    @_builtins.property
    @pulumi.getter
    def https(self) -> pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckHttpArgs']]]:
        """
        HTTP health check configuration.
        """
        return pulumi.get(self, "https")

    @https.setter
    def https(self, value: pulumi.Input[Sequence[pulumi.Input['ContainerHealthCheckHttpArgs']]]):
        pulumi.set(self, "https", value)

    @_builtins.property
    @pulumi.getter
    def interval(self) -> pulumi.Input[_builtins.str]:
        """
        Period between health checks (in seconds).
        """
        return pulumi.get(self, "interval")

    @interval.setter
    def interval(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "interval", value)


if not MYPY:
    class ContainerHealthCheckHttpArgsDict(TypedDict):
        path: pulumi.Input[_builtins.str]
        """
        Path to use for the HTTP health check.
        """
elif False:
    ContainerHealthCheckHttpArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ContainerHealthCheckHttpArgs:
    def __init__(__self__, *,
                 path: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] path: Path to use for the HTTP health check.
        """
        pulumi.set(__self__, "path", path)

    @_builtins.property
    @pulumi.getter
    def path(self) -> pulumi.Input[_builtins.str]:
        """
        Path to use for the HTTP health check.
        """
        return pulumi.get(self, "path")

    @path.setter
    def path(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "path", value)


if not MYPY:
    class ContainerScalingOptionArgsDict(TypedDict):
        concurrent_requests_threshold: NotRequired[pulumi.Input[_builtins.int]]
        """
        Scale depending on the number of concurrent requests being processed per container instance.
        """
        cpu_usage_threshold: NotRequired[pulumi.Input[_builtins.int]]
        """
        Scale depending on the CPU usage of a container instance.
        """
        memory_usage_threshold: NotRequired[pulumi.Input[_builtins.int]]
        """
        Scale depending on the memory usage of a container instance.
        """
elif False:
    ContainerScalingOptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class ContainerScalingOptionArgs:
    def __init__(__self__, *,
                 concurrent_requests_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 cpu_usage_threshold: Optional[pulumi.Input[_builtins.int]] = None,
                 memory_usage_threshold: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.int] concurrent_requests_threshold: Scale depending on the number of concurrent requests being processed per container instance.
        :param pulumi.Input[_builtins.int] cpu_usage_threshold: Scale depending on the CPU usage of a container instance.
        :param pulumi.Input[_builtins.int] memory_usage_threshold: Scale depending on the memory usage of a container instance.
        """
        if concurrent_requests_threshold is not None:
            pulumi.set(__self__, "concurrent_requests_threshold", concurrent_requests_threshold)
        if cpu_usage_threshold is not None:
            pulumi.set(__self__, "cpu_usage_threshold", cpu_usage_threshold)
        if memory_usage_threshold is not None:
            pulumi.set(__self__, "memory_usage_threshold", memory_usage_threshold)

    @_builtins.property
    @pulumi.getter(name="concurrentRequestsThreshold")
    def concurrent_requests_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Scale depending on the number of concurrent requests being processed per container instance.
        """
        return pulumi.get(self, "concurrent_requests_threshold")

    @concurrent_requests_threshold.setter
    def concurrent_requests_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "concurrent_requests_threshold", value)

    @_builtins.property
    @pulumi.getter(name="cpuUsageThreshold")
    def cpu_usage_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Scale depending on the CPU usage of a container instance.
        """
        return pulumi.get(self, "cpu_usage_threshold")

    @cpu_usage_threshold.setter
    def cpu_usage_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "cpu_usage_threshold", value)

    @_builtins.property
    @pulumi.getter(name="memoryUsageThreshold")
    def memory_usage_threshold(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Scale depending on the memory usage of a container instance.
        """
        return pulumi.get(self, "memory_usage_threshold")

    @memory_usage_threshold.setter
    def memory_usage_threshold(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "memory_usage_threshold", value)


if not MYPY:
    class TriggerNatsArgsDict(TypedDict):
        subject: pulumi.Input[_builtins.str]
        """
        The subject to listen to.
        """
        account_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        unique identifier of the Messaging and Queuing NATS account.
        """
        project_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        THe ID of the project that contains the Messaging and Queuing NATS account (defaults to provider `project_id`)
        """
        region: NotRequired[pulumi.Input[_builtins.str]]
        """
        Region where the Messaging and Queuing NATS account is enabled (defaults to provider `region`)
        """
elif False:
    TriggerNatsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TriggerNatsArgs:
    def __init__(__self__, *,
                 subject: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] subject: The subject to listen to.
        :param pulumi.Input[_builtins.str] account_id: unique identifier of the Messaging and Queuing NATS account.
        :param pulumi.Input[_builtins.str] project_id: THe ID of the project that contains the Messaging and Queuing NATS account (defaults to provider `project_id`)
        :param pulumi.Input[_builtins.str] region: Region where the Messaging and Queuing NATS account is enabled (defaults to provider `region`)
        """
        pulumi.set(__self__, "subject", subject)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def subject(self) -> pulumi.Input[_builtins.str]:
        """
        The subject to listen to.
        """
        return pulumi.get(self, "subject")

    @subject.setter
    def subject(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "subject", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        unique identifier of the Messaging and Queuing NATS account.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        THe ID of the project that contains the Messaging and Queuing NATS account (defaults to provider `project_id`)
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region where the Messaging and Queuing NATS account is enabled (defaults to provider `region`)
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)


if not MYPY:
    class TriggerSqsArgsDict(TypedDict):
        queue: pulumi.Input[_builtins.str]
        """
        The name of the SQS queue.
        """
        namespace_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        ID of the Messaging and Queuing namespace. This argument is deprecated.
        """
        project_id: NotRequired[pulumi.Input[_builtins.str]]
        """
        The ID of the project in which SQS is enabled, (defaults to provider `project_id`)
        """
        region: NotRequired[pulumi.Input[_builtins.str]]
        """
        Region where SQS is enabled (defaults to provider `region`)
        """
elif False:
    TriggerSqsArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class TriggerSqsArgs:
    def __init__(__self__, *,
                 queue: pulumi.Input[_builtins.str],
                 namespace_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] queue: The name of the SQS queue.
        :param pulumi.Input[_builtins.str] namespace_id: ID of the Messaging and Queuing namespace. This argument is deprecated.
        :param pulumi.Input[_builtins.str] project_id: The ID of the project in which SQS is enabled, (defaults to provider `project_id`)
        :param pulumi.Input[_builtins.str] region: Region where SQS is enabled (defaults to provider `region`)
        """
        pulumi.set(__self__, "queue", queue)
        if namespace_id is not None:
            warnings.warn("""The 'namespace_id' field is deprecated and will be removed in the next major version. It is no longer necessary to specify it""", DeprecationWarning)
            pulumi.log.warn("""namespace_id is deprecated: The 'namespace_id' field is deprecated and will be removed in the next major version. It is no longer necessary to specify it""")
        if namespace_id is not None:
            pulumi.set(__self__, "namespace_id", namespace_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if region is not None:
            pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter
    def queue(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the SQS queue.
        """
        return pulumi.get(self, "queue")

    @queue.setter
    def queue(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "queue", value)

    @_builtins.property
    @pulumi.getter(name="namespaceId")
    @_utilities.deprecated("""The 'namespace_id' field is deprecated and will be removed in the next major version. It is no longer necessary to specify it""")
    def namespace_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the Messaging and Queuing namespace. This argument is deprecated.
        """
        return pulumi.get(self, "namespace_id")

    @namespace_id.setter
    def namespace_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "namespace_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the project in which SQS is enabled, (defaults to provider `project_id`)
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region where SQS is enabled (defaults to provider `region`)
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'SecretEphemeralPolicy',
    'SecretVersion',
    'GetSecretEphemeralPolicyResult',
    'GetSecretVersionResult',
]

@pulumi.output_type
class SecretEphemeralPolicy(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "expiresOnceAccessed":
            suggest = "expires_once_accessed"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SecretEphemeralPolicy. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SecretEphemeralPolicy.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SecretEphemeralPolicy.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 action: _builtins.str,
                 expires_once_accessed: Optional[_builtins.bool] = None,
                 ttl: Optional[_builtins.str] = None):
        """
        :param _builtins.str action: Action to perform when the version of a secret expires. Available values can be found in [SDK constants](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/secret/v1beta1#pkg-constants).
        :param _builtins.bool expires_once_accessed: True if the secret version expires after a single user access.
        :param _builtins.str ttl: Time frame, from one second and up to one year, during which the secret's versions are valid. Has to be specified in [Go Duration format](https://pkg.go.dev/time#ParseDuration) (ex: "30m", "24h").
        """
        pulumi.set(__self__, "action", action)
        if expires_once_accessed is not None:
            pulumi.set(__self__, "expires_once_accessed", expires_once_accessed)
        if ttl is not None:
            pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter
    def action(self) -> _builtins.str:
        """
        Action to perform when the version of a secret expires. Available values can be found in [SDK constants](https://pkg.go.dev/github.com/scaleway/scaleway-sdk-go@master/api/secret/v1beta1#pkg-constants).
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="expiresOnceAccessed")
    def expires_once_accessed(self) -> Optional[_builtins.bool]:
        """
        True if the secret version expires after a single user access.
        """
        return pulumi.get(self, "expires_once_accessed")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> Optional[_builtins.str]:
        """
        Time frame, from one second and up to one year, during which the secret's versions are valid. Has to be specified in [Go Duration format](https://pkg.go.dev/time#ParseDuration) (ex: "30m", "24h").
        """
        return pulumi.get(self, "ttl")


@pulumi.output_type
class SecretVersion(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "createdAt":
            suggest = "created_at"
        elif key == "secretId":
            suggest = "secret_id"
        elif key == "updatedAt":
            suggest = "updated_at"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in SecretVersion. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        SecretVersion.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        SecretVersion.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 created_at: Optional[_builtins.str] = None,
                 description: Optional[_builtins.str] = None,
                 latest: Optional[_builtins.bool] = None,
                 revision: Optional[_builtins.str] = None,
                 secret_id: Optional[_builtins.str] = None,
                 status: Optional[_builtins.str] = None,
                 updated_at: Optional[_builtins.str] = None):
        """
        :param _builtins.str created_at: Date and time of the secret's creation (in RFC 3339 format).
        :param _builtins.str description: Description of the secret (e.g. `my-new-description`).
        :param _builtins.bool latest: Returns true if the version is the latest.
        :param _builtins.str revision: The revision of secret version
        :param _builtins.str secret_id: The secret ID associated with this version
        :param _builtins.str status: The status of the secret.
        :param _builtins.str updated_at: Date and time of the secret's last update (in RFC 3339 format).
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if latest is not None:
            pulumi.set(__self__, "latest", latest)
        if revision is not None:
            pulumi.set(__self__, "revision", revision)
        if secret_id is not None:
            pulumi.set(__self__, "secret_id", secret_id)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[_builtins.str]:
        """
        Date and time of the secret's creation (in RFC 3339 format).
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Description of the secret (e.g. `my-new-description`).
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def latest(self) -> Optional[_builtins.bool]:
        """
        Returns true if the version is the latest.
        """
        return pulumi.get(self, "latest")

    @_builtins.property
    @pulumi.getter
    def revision(self) -> Optional[_builtins.str]:
        """
        The revision of secret version
        """
        return pulumi.get(self, "revision")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> Optional[_builtins.str]:
        """
        The secret ID associated with this version
        """
        return pulumi.get(self, "secret_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[_builtins.str]:
        """
        The status of the secret.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[_builtins.str]:
        """
        Date and time of the secret's last update (in RFC 3339 format).
        """
        return pulumi.get(self, "updated_at")


@pulumi.output_type
class GetSecretEphemeralPolicyResult(dict):
    def __init__(__self__, *,
                 action: _builtins.str,
                 expires_once_accessed: _builtins.bool,
                 ttl: _builtins.str):
        """
        :param _builtins.str action: Action to perform when the version of a secret expires.
        :param _builtins.bool expires_once_accessed: True if the secret version expires after a single user access.
        :param _builtins.str ttl: Time frame, from one second and up to one year, during which the secret's versions are valid. Has to be specified in Go Duration format
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "expires_once_accessed", expires_once_accessed)
        pulumi.set(__self__, "ttl", ttl)

    @_builtins.property
    @pulumi.getter
    def action(self) -> _builtins.str:
        """
        Action to perform when the version of a secret expires.
        """
        return pulumi.get(self, "action")

    @_builtins.property
    @pulumi.getter(name="expiresOnceAccessed")
    def expires_once_accessed(self) -> _builtins.bool:
        """
        True if the secret version expires after a single user access.
        """
        return pulumi.get(self, "expires_once_accessed")

    @_builtins.property
    @pulumi.getter
    def ttl(self) -> _builtins.str:
        """
        Time frame, from one second and up to one year, during which the secret's versions are valid. Has to be specified in Go Duration format
        """
        return pulumi.get(self, "ttl")


@pulumi.output_type
class GetSecretVersionResult(dict):
    def __init__(__self__, *,
                 created_at: _builtins.str,
                 description: _builtins.str,
                 latest: _builtins.bool,
                 revision: _builtins.str,
                 secret_id: _builtins.str,
                 status: _builtins.str,
                 updated_at: _builtins.str):
        """
        :param _builtins.str created_at: Date and time of secret version's creation (RFC 3339 format)
        :param _builtins.str description: Description of the secret version
        :param _builtins.bool latest: Returns true if the version is the latest.
        :param _builtins.str revision: The revision of secret version
        :param _builtins.str secret_id: The ID of the secret.
               Only one of `name` and `secret_id` should be specified.
        :param _builtins.str status: Status of the secret version
        :param _builtins.str updated_at: Date and time of secret version's creation (RFC 3339 format)
        """
        pulumi.set(__self__, "created_at", created_at)
        pulumi.set(__self__, "description", description)
        pulumi.set(__self__, "latest", latest)
        pulumi.set(__self__, "revision", revision)
        pulumi.set(__self__, "secret_id", secret_id)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Date and time of secret version's creation (RFC 3339 format)
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the secret version
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def latest(self) -> _builtins.bool:
        """
        Returns true if the version is the latest.
        """
        return pulumi.get(self, "latest")

    @_builtins.property
    @pulumi.getter
    def revision(self) -> _builtins.str:
        """
        The revision of secret version
        """
        return pulumi.get(self, "revision")

    @_builtins.property
    @pulumi.getter(name="secretId")
    def secret_id(self) -> _builtins.str:
        """
        The ID of the secret.
        Only one of `name` and `secret_id` should be specified.
        """
        return pulumi.get(self, "secret_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of the secret version
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Date and time of secret version's creation (RFC 3339 format)
        """
        return pulumi.get(self, "updated_at")


